# CircuitPython program for ESP32-C3 Supermini board
# This program interfaces with an I2C OLED display (using the SSD1306 driver)
# and an AHT20 sensor to measure and display temperature and humidity.
# The measurement results are updated on the display every 2 seconds.

import time   # Import the time library for delays
import board  # Import board library for pin definitions
import busio  # Import busio for I2C communication
import adafruit_ahtx0  # Import library for the AHT20 sensor
import adafruit_ssd1306  # Import library for the SSD1306 OLED display driver

# Initialize I2C communication on the designated pins (SCL and SDA) with a 400kHz frequency
i2c = busio.I2C(board.SCL, board.SDA, frequency=400000)

# Create an instance of the AHT20 sensor
sensor = adafruit_ahtx0.AHTx0(i2c)

# Create an instance of the SSD1306 OLED display with resolution 128x64 and I2C communication
# The OLED uses address 0x3C and does not use external power (external_vcc=False)
oled = adafruit_ssd1306.SSD1306_I2C(128, 64, i2c, addr=0x3c, external_vcc=False)

# Rotate the OLED display for correct orientation
oled.rotate(1)

# Infinite loop to continuously read and display sensor data
while True:
    # Read temperature and humidity values from the AHT20 sensor
    temperature = sensor.temperature  # Get temperature in Celsius
    humidity = sensor.relative_humidity  # Get relative humidity in percentage

    # Clear the OLED display for new data
    oled.fill(0)

    # Display temperature and humidity data on the OLED
    # Display temperature (e.g., "T: 22.5 C") at position (0, 0)
    oled.text(f"T: {temperature:.1f} C", 0, 0, 1, size=2)
    # Display humidity (e.g., "H: 45.3 %") at position (0, 32)
    oled.text(f"H: {humidity:.1f} %", 0, 32, 1, size=2)

    # Send updated content to the OLED display
    oled.show()

    # Wait for 2 seconds before the next update
    time.sleep(2)
